% This script loads the eye tracking data and shows the fixation points
% (see description on the paper that explains how the raw data has been
% processed).
%
% The matlab files contain the next information:
% There are there files, one for each search task:
%    people search: eyedata/people_search.mat
%    cup/mug/glass search: eyedata/cup_search.mat
%    painting search: eyedata/painting_search.mat
%
% each file contains a struct:
%    expe.imagefilename
%        .targetPresent
%        .eye 
%
% expe.eye contains the eye coordinates for all images/participants.
%       expe.eye{imagenumber,participant number}.x  = vector with all fixations
%       expe.eye{imagenumber,participant number}.y
%
% If you find bugs in this code, please, contact:
% A. Torralba 
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Citation:
%
% Torralba, A., Oliva, A., Castelhano, M. S., and Henderson, J. M. (2006).
% "Contextual guidance of eye movements and attention in real-world scenes: 
% The role of global features in object search". Psychological Review, 113, 766-786.

clear all

imagesfolder = 'images'; % put here the path for the images

plotstyle = {'o-', 'LineWidth' ,2, 'MarkerEdgeColor', 'y','MarkerFaceColor','r', 'markersize', 8};

% Show the three tasks
for task = 1:3
    switch task
        case 1
            Task = 'people search';
            load('people_search.mat')
        case 2
            Task = 'cup search';
            load('cup_search.mat')
        case 3
            Task = 'painting search';
            load('painting_search.mat')
    end

    [Nimages, Nparticipants] = size(expe.eye);
    
    % Show all images for this task
    for i = 1:Nimages
        % Read image
        img = imread(fullfile(imagesfolder, expe.imagefilename{i}));

        figure('name', sprintf('Task %s, image: %s, target present/absent (1/0) = %d', Task, expe.imagefilename{i}, expe.targetPresent(i)))

        % Show all fixations for each participant
        for p = 1:Nparticipants
            subplot(3,3,p)
            imshow(img) % show image
            hold on
            plot(expe.eye{i,p}.x, expe.eye{i,p}.y, plotstyle{:}) % plot fixations
            title(sprintf('Image %d, Participant %d', i, p))
        end
        drawnow
    end
end


